@@ -50,7 +50,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 19941386 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 20173689 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -422,7 +422,7 @@ append_file_or_dir_silent /usr/share/nvidia/nvidia-application-profiles-*-rc
     for i in /var/log/messages /var/log/kernel.log ; do
         if [ -f $i -a -r $i ]; then
             echo "  $i:"
-            ( cat $i | grep -e NVRM -e nvidia-modeset ) 2> /dev/null
+            ( cat $i | grep -e NVRM -e nvidia- ) 2> /dev/null
         else
             echo "$i is not readable"
         fi
