@@ -84,6 +84,11 @@ typedef struct {
     int (*alloc_stack)(nvidia_modeset_stack_ptr *sp);
     void (*free_stack)(nvidia_modeset_stack_ptr sp);
 
+    /*
+     * Return list of gpu ids probed by nvidia driver.
+     */
+    NvBool (*get_gpuid_list)(NvU32 *gpu_ids, NvU32 *gpu_count);
+
     /*
      * {open,close}_gpu() raise and lower the reference count of the
      * specified GPU.  This is equivalent to opening and closing a
