@@ -320,7 +320,8 @@ struct nvkms_timer_t {
     NvBool isRefPtr;
     NvBool callout_created;
     nvkms_timer_proc_t *proc;
-    void *data;
+    void *dataPtr;
+    NvU32 dataU32;
     LIST_ENTRY(nvkms_timer_t) timers_list;
 };
 
@@ -335,7 +336,7 @@ static struct {
 static void nvkms_taskqueue_callback(void *arg, int pending)
 {
     struct nvkms_timer_t *timer = arg;
-    void *data;
+    void *dataPtr;
 
     /*
      * We can delete this timer from pending timers list - it's being
@@ -360,16 +361,16 @@ static void nvkms_taskqueue_callback(void *arg, int pending)
     if (timer->isRefPtr) {
         // If the object this timer refers to was destroyed, treat the timer as
         // canceled.
-        data = nvkms_dec_ref(timer->data);
-        if (!data) {
+        dataPtr = nvkms_dec_ref(timer->dataPtr);
+        if (!dataPtr) {
             timer->cancel = NV_TRUE;
         }
     } else {
-        data = timer->data;
+        dataPtr = timer->dataPtr;
     }
 
     if (!timer->cancel) {
-        timer->proc(data);
+        timer->proc(dataPtr, timer->dataU32);
         timer->complete = NV_TRUE;
     }
 
@@ -390,14 +391,15 @@ static void nvkms_callout_callback(void *arg)
 
 static void
 nvkms_init_timer(struct nvkms_timer_t *timer, nvkms_timer_proc_t *proc,
-                 void *arg, NvBool isRefPtr, NvU64 usec)
+                 void *dataPtr, NvU32 dataU32, NvBool isRefPtr, NvU64 usec)
 {
     timer->cancel = NV_FALSE;
     timer->complete = NV_FALSE;
     timer->isRefPtr = isRefPtr;
 
     timer->proc = proc;
-    timer->data = arg;
+    timer->dataPtr = dataPtr;
+    timer->dataU32 = dataU32;
 
     TASK_INIT(&timer->task,
               0 /* priority */,
@@ -428,20 +430,22 @@ nvkms_init_timer(struct nvkms_timer_t *timer, nvkms_timer_proc_t *proc,
 }
 
 nvkms_timer_handle_t*
-NVKMS_API_CALL nvkms_alloc_timer(nvkms_timer_proc_t *proc, void *arg,
+NVKMS_API_CALL nvkms_alloc_timer(nvkms_timer_proc_t *proc,
+                                 void *dataPtr, NvU32 dataU32,
                                  NvU64 usec)
 {
     // nvkms_alloc_timer cannot be called from an interrupt context.
     struct nvkms_timer_t *timer = nvkms_alloc(sizeof(*timer), NV_TRUE);
     if (timer) {
-        nvkms_init_timer(timer, proc, arg, NV_FALSE, usec);
+        nvkms_init_timer(timer, proc, dataPtr, dataU32, NV_FALSE, usec);
     }
     return timer;
 }
 
 NvBool NVKMS_API_CALL
 nvkms_alloc_timer_with_ref_ptr(nvkms_timer_proc_t *proc,
-                               struct nvkms_ref_ptr *ref_ptr, NvU64 usec)
+                               struct nvkms_ref_ptr *ref_ptr,
+                               NvU32 dataU32, NvU64 usec)
 {
     // nvkms_alloc_timer_with_ref_ptr is called from an interrupt bottom half
     // handler.
@@ -452,7 +456,7 @@ nvkms_alloc_timer_with_ref_ptr(nvkms_timer_proc_t *proc,
         // Reference the ref_ptr to make sure that it doesn't get freed before
         // the timer fires.
         nvkms_inc_ref(ref_ptr);
-        nvkms_init_timer(timer, proc, ref_ptr, NV_TRUE, usec);
+        nvkms_init_timer(timer, proc, ref_ptr, dataU32, NV_TRUE, usec);
     }
 
     return timer != NULL;
@@ -652,6 +656,36 @@ void NVKMS_API_CALL nvkms_close_gpu(NvU32 gpuId)
     __rm_ops.close_gpu(gpuId, nvkms_nvidia_stack);
 }
 
+NvBool NVKMS_API_CALL nvkms_list_gpus(NvU32 *gpu_ids, NvU32 *gpu_count)
+{
+    return NV_FALSE;
+}
+
+/*************************************************************************
+ * NVKMS interface for kernel space NVKMS clients like KAPI
+ *************************************************************************/
+
+struct nvkms_per_open* NVKMS_API_CALL nvkms_open_from_kapi
+(
+    struct NvKmsKapiDevice *device
+)
+{
+    return NULL;
+}
+
+void NVKMS_API_CALL nvkms_close_from_kapi(struct nvkms_per_open *popen)
+{
+}
+
+NvBool NVKMS_API_CALL nvkms_ioctl_from_kapi
+(
+    struct nvkms_per_open *popen,
+    NvU32 cmd, void *params_address, const size_t params_size
+)
+{
+    return NV_FALSE;
+}
+
 /*************************************************************************
  * File operation callback functions.
  *************************************************************************/
@@ -708,7 +742,7 @@ static int nvkms_ioctl(
     sx_xlock(&nvkms_lock);
     ret = nvKmsIoctl(popen->data,
                      params->cmd,
-                     NVKMS_IOCTL_FROM_USER_SPACE,
+                     NVKMS_CLIENT_USER_SPACE,
                      params->address,
                      params->size);
     sx_xunlock(&nvkms_lock);
@@ -988,7 +1022,7 @@ nvidia_modeset_loader(struct module *m, int what, void *arg)
                     /*  We've deactivated timer so we need to clean after it */
                     LIST_REMOVE(timer, timers_list);
                     if (timer->isRefPtr) {
-                        nvkms_dec_ref(timer->data);
+                        nvkms_dec_ref(timer->dataPtr);
                     }
                     nvkms_free(timer, sizeof(*timer));
                 }
