@@ -11,6 +11,8 @@
 #include "nvtypes.h"
 #include <stddef.h> /* size_t */
 
+#include "nvkms-kapi.h"
+
 /*
  * On Linux-x86, the kernel's function calling convention may pass
  * parameters in registers.  Force functions called to and from core
@@ -24,14 +26,19 @@
 
 typedef struct nvkms_per_open nvkms_per_open_handle_t;
 
-enum NvKmsIoctlOrigin {
-    NVKMS_IOCTL_FROM_USER_SPACE,
-    NVKMS_IOCTL_FROM_KERNEL_SPACE,
+typedef struct {
+    const char *name;
+    NVKMS_API_CALL void (*func)(char **buffer, size_t *size);
+} nvkms_proc_files_t;
+
+enum NvKmsClientType {
+    NVKMS_CLIENT_USER_SPACE,
+    NVKMS_CLIENT_KERNEL_SPACE,
 };
 
 NvBool NVKMS_API_CALL nvKmsIoctl(void *pOpenVoid,
                                  NvU32 cmd,
-                                 const enum NvKmsIoctlOrigin ioctlOrigin,
+                                 const enum NvKmsClientType clientType,
                                  NvU64 paramsAddress,
                                  const size_t paramSize);
 
@@ -46,4 +53,16 @@ void NVKMS_API_CALL nvKmsModuleUnload(void);
 void NVKMS_API_CALL nvKmsSuspend(NvU32 gpuId);
 void NVKMS_API_CALL nvKmsResume(NvU32 gpuId);
 
+void NVKMS_API_CALL nvKmsGetProcFiles(const nvkms_proc_files_t **ppProcFiles);
+
+void NVKMS_API_CALL nvKmsKapiHandleEventQueueChange
+(
+    struct NvKmsKapiDevice *device
+);
+
+NvBool NVKMS_API_CALL nvKmsKapiGetFunctionsTableInternal
+(
+    struct NvKmsKapiFunctionsTable *funcsTable
+);
+
 #endif /* __NV_KMS_H__ */
