@@ -13,6 +13,7 @@
 #define _NV_H_
 
 #include <nvtypes.h>
+#include <nvCpuUuid.h>
 #include <stdarg.h>
 
 #if !defined(NV_MIN)
@@ -363,19 +364,22 @@ typedef struct gpuSession           *nvgpuSessionHandle_t;
 typedef struct gpuAddressSpace      *nvgpuAddressSpaceHandle_t;
 typedef struct gpuChannel           *nvgpuChannelHandle_t;
 typedef struct gpuObject            *nvgpuObjectHandle_t;
-typedef struct gpuChannelInfo       *nvgpuChannelInfo_t;
-typedef struct gpuCaps              *nvgpuCaps_t;
+typedef struct UvmGpuChannelPointers_tag *nvgpuChannelInfo_t;
+typedef struct UvmGpuCaps_tag       *nvgpuCaps_t;
 typedef struct gpuAllocInfo         *nvgpuAllocInfo_t;
 typedef struct gpuSurfaceMappingInfo *nvgpuSurfaceMapInfo_t;
+typedef struct UvmGpuP2PCapsParams_tag *nvgpuP2PCapsParams_t;
 typedef struct gpuVaAllocInfo       *nvgpuVaAllocInfo_t;
 typedef struct gpuMapInfo           *nvgpuMapInfo_t;
 typedef struct gpuFbInfo            *nvgpuFbInfo_t;
 typedef struct gpuFaultInfo         *nvgpuFaultInfo_t;
-typedef struct gpuInfo              *nvgpuInfo_t;
+typedef struct gpuAccessCntrInfo    *nvgpuAccessCntrInfo_t;
+typedef struct UvmGpuInfo_tag       *nvgpuInfo_t;
 typedef struct gpuPageLevelInfo     *nvgpuPageLevelInfo_t;
 typedef struct gpuChannelPhysInfo   *nvgpuChannelPhysInfo_t;
 typedef struct gpuChannelCtxBufferInfo *nvgpuChannelCtxBufferInfo_t;
 typedef struct gpuChannelBufferVa   *nvgpuChannelBufferVa_t;
+typedef struct gpuPmaAllocationOptions *nvgpuPmaAllocationOptions_t;
 
 /*
  * flags
@@ -594,7 +598,7 @@ NV_STATUS  NV_API_CALL  nv_dma_unmap_pages       (nv_state_t *, NvU64, NvU64 *,
 NV_STATUS  NV_API_CALL  nv_dma_map_alloc         (nv_state_t *, NvU64, NvU64 *, void **);
 NV_STATUS  NV_API_CALL  nv_dma_unmap_alloc       (nv_state_t *, NvU64, NvU64 *, void **);
 
-NV_STATUS  NV_API_CALL  nv_dma_map_peer          (nv_state_t *, nv_aperture_t *, NvU64, NvU64 *);
+NV_STATUS  NV_API_CALL  nv_dma_map_peer          (nv_state_t *, nv_state_t *, NvU8, NvU64, NvU64 *);
 NV_STATUS  NV_API_CALL  nv_dma_unmap_peer        (nv_state_t *, NvU64, NvU64 *);
 
 NvS32  NV_API_CALL  nv_start_rc_timer            (nv_state_t *);
@@ -603,8 +607,6 @@ NvS32  NV_API_CALL  nv_stop_rc_timer             (nv_state_t *);
 void   NV_API_CALL  nv_post_event                (nv_state_t *, nv_event_t *, NvHandle, NvU32, NvBool);
 NvS32  NV_API_CALL  nv_get_event                 (nv_state_t *, void *, nv_event_t *, NvU32 *);
 
-NvS32  NV_API_CALL  nv_no_incoherent_mappings    (void);
-
 void   NV_API_CALL  nv_verify_pci_config         (nv_state_t *, BOOL);
 
 void*  NV_API_CALL  nv_i2c_add_adapter           (nv_state_t *, NvU32);
@@ -701,17 +703,24 @@ NV_STATUS  NV_API_CALL  rm_log_gpu_crash          (nv_stack_t *, nv_state_t *);
 
 NV_STATUS  NV_API_CALL  rm_gpu_ops_create_session (nvidia_stack_t *, nvgpuSessionHandle_t *);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_destroy_session (nvidia_stack_t *, nvgpuSessionHandle_t);
-NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create(nvidia_stack_t *, nvgpuSessionHandle_t, unsigned long long, unsigned long long, nvgpuAddressSpaceHandle_t *, unsigned long long, unsigned long long);
-NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create_mirrored(nvidia_stack_t *, nvgpuSessionHandle_t, unsigned long long, unsigned long long, nvgpuAddressSpaceHandle_t *);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create(nvidia_stack_t *, nvgpuSessionHandle_t, NvProcessorUuid *, nvgpuAddressSpaceHandle_t *, unsigned long long, unsigned long long);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create_mirrored(nvidia_stack_t *, nvgpuSessionHandle_t, NvProcessorUuid *, nvgpuAddressSpaceHandle_t *);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_dup_address_space(nvidia_stack_t *, nvgpuSessionHandle_t, NvU8*, NvHandle, NvHandle, nvgpuAddressSpaceHandle_t *);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_destroy(nvidia_stack_t *, nvgpuAddressSpaceHandle_t);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_fb(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *, nvgpuAllocInfo_t);
-NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_gpu_va(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *, nvgpuVaAllocInfo_t);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_gpu_pa(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *, nvgpuAllocInfo_t);
 
+NV_STATUS  NV_API_CALL  rm_gpu_ops_pma_alloc_pages(nvidia_stack_t *, void *, NvLength, NvU32 , nvgpuPmaAllocationOptions_t, NvU64 *);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_pma_free_pages(nvidia_stack_t *, void *, NvU64 *, NvLength , NvU32, NvU32);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_pma_pin_pages(nvidia_stack_t *, void *, NvU64 *, NvLength , NvU32);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_pma_unpin_pages(nvidia_stack_t *, void *, NvU64 *, NvLength , NvU32);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_get_pma_object(nvidia_stack_t *, NvProcessorUuid *, void **);
+
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_sys(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *, nvgpuAllocInfo_t);
 
-NV_STATUS  NV_API_CALL  rm_gpu_ops_get_surface_map_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, nvgpuSurfaceMapInfo_t);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_get_surface_map_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuSurfaceMapInfo_t);
+
+NV_STATUS  NV_API_CALL  rm_gpu_ops_get_p2p_caps(nvidia_stack_t *, nvgpuP2PCapsParams_t);
 
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_cpu_map(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64, NvLength, void **, NvU32);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_cpu_ummap(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, void*);
@@ -720,13 +729,12 @@ NV_STATUS  NV_API_CALL  rm_gpu_ops_channel_destroy(nvidia_stack_t *, nvgpuChanne
 const char*  NV_API_CALL  rm_gpu_ops_channel_translate_error(nvidia_stack_t *, NvU32);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_copy_engine_allocate(nvidia_stack_t *, nvgpuChannelHandle_t, NvU32, NvU32*, nvgpuObjectHandle_t *);
 NV_STATUS  NV_API_CALL rm_gpu_ops_memory_free(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64);
-NV_STATUS  NV_API_CALL rm_gpu_ops_memory_free_va(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64);
 NV_STATUS  NV_API_CALL rm_gpu_ops_memory_free_pa(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64);
 NV_STATUS  NV_API_CALL rm_gpu_ops_query_caps(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuCaps_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_attached_uuids(nvidia_stack_t *, NvU8 *pUuidList, unsigned *numGpus);
-NV_STATUS  NV_API_CALL rm_gpu_ops_get_gpu_info(nvidia_stack_t *, NvU8 *pUuid, unsigned uuidLength, nvgpuInfo_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_gpu_info(nvidia_stack_t *, NvProcessorUuid *pUuid, nvgpuInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_uvm_priv_region(NvU64 *pPrivRegionStart, NvU64 *pPrivRegionLength);
-NV_STATUS  NV_API_CALL rm_gpu_ops_service_device_interrupts_rm(nvidia_stack_t *, nvgpuChannelHandle_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_service_device_interrupts_rm(nvidia_stack_t *, nvgpuAddressSpaceHandle_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_check_ecc_error_slowpath(nvidia_stack_t *, nvgpuChannelHandle_t, NvBool *);
 NV_STATUS  NV_API_CALL rm_gpu_ops_kill_channel(nvidia_stack_t *, nvgpuChannelHandle_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_gmmu_fmt(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, void **);
@@ -738,19 +746,26 @@ NV_STATUS  NV_API_CALL rm_gpu_ops_free_duped_handle(nvidia_stack_t *, nvgpuAddre
 NV_STATUS  NV_API_CALL rm_gpu_ops_check_pseudo_p9(nvidia_stack_t *sp, nvgpuAddressSpaceHandle_t vaspace, NvBool *isPseudoP9);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_fb_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuFbInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_gpu_ids(nvidia_stack_t *sp, NvU8 *pUuid, unsigned uuidLength, NvU32 *pDeviceId, NvU32 *pSubdeviceId);
+NV_STATUS NV_API_CALL rm_gpu_ops_own_page_fault_intr(nvidia_stack_t *, NvU8 *, unsigned, NvBool);
 NV_STATUS  NV_API_CALL rm_gpu_ops_init_fault_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuFaultInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_destroy_fault_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuFaultInfo_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_init_access_cntr_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuAccessCntrInfo_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_destroy_access_cntr_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuAccessCntrInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_page_level_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64, nvgpuPageLevelInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_channel_phys_info(nvidia_stack_t *, NvHandle, NvHandle, nvgpuChannelPhysInfo_t);
-void       NV_API_CALL rm_gpu_ops_free_channel_inst_ptr(nvidia_stack_t *, void*);
+void       NV_API_CALL rm_gpu_ops_free_mem_handles(nvidia_stack_t *, void**, NvU32);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_set_page_directory (nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64, unsigned, NvBool);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_unset_page_directory (nvidia_stack_t *, nvgpuAddressSpaceHandle_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_bind_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, NvU32, nvgpuChannelBufferVa_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_stop_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, NvP64);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_ctx_buffer_count(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU32 *);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_ctx_buffer_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, NvU32, nvgpuChannelCtxBufferInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_ctx_buffer_phys_info(nvidia_stack_t *, void *, NvU64, NvU64 *);
 NV_STATUS  NV_API_CALL rm_gpu_ops_validate_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, NvHandle);
-NV_STATUS  NV_API_CALL rm_gpu_ops_bind_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, NvU32, nvgpuChannelBufferVa_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_unbind_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, NvU32, NvU64*);
+NV_STATUS  NV_API_CALL rm_gpu_ops_stop_vaspace_channels(nvidia_stack_t *, nvgpuSessionHandle_t, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle);
+NV_STATUS  NV_API_CALL rm_gpu_ops_p2p_object_create(nvidia_stack_t *, nvgpuSessionHandle_t, NvProcessorUuid *, NvProcessorUuid *, NvHandle *);
+void       NV_API_CALL rm_gpu_ops_p2p_object_destroy(nvidia_stack_t *, nvgpuSessionHandle_t, NvHandle);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_big_page_size(nvidia_stack_t*, nvgpuAddressSpaceHandle_t, NvU32 *);
 
 void       NV_API_CALL rm_kernel_rmapi_op(nvidia_stack_t *sp, void *ops_cmd);
 
