@@ -774,11 +774,6 @@ int nvidia_modevent(
     return 0;
 }
 
-NvS32 NV_API_CALL nv_no_incoherent_mappings(void)
-{
-    return 1;
-}
-
 void nv_lock_api(nv_state_t *nv)
 {
     struct nvidia_softc *sc = nv->os_state;
@@ -1560,10 +1555,11 @@ NV_STATUS NV_API_CALL nv_dma_unmap_alloc(
 }
 
 NV_STATUS NV_API_CALL nv_dma_map_peer(
-    nv_state_t    *nv,
-    nv_aperture_t *aperture,
-    NvU64          page_count,
-    NvU64         *va_array
+    nv_state_t *nv,
+    nv_state_t *peer,
+    NvU8        bar_index,
+    NvU64       page_count,
+    NvU64      *va
 )
 {
     return NV_ERR_NOT_SUPPORTED;
@@ -1572,7 +1568,7 @@ NV_STATUS NV_API_CALL nv_dma_map_peer(
 NV_STATUS NV_API_CALL nv_dma_unmap_peer(
     nv_state_t *nv,
     NvU64       page_count,
-    NvU64      *va_array
+    NvU64      *va
 )
 {
     return NV_ERR_NOT_SUPPORTED;
