@@ -149,6 +149,7 @@ BOOL        NV_API_CALL  os_iommu_is_snooping_enabled(void);
 NvBool      NV_API_CALL  os_is_xen_dom0              (void);
 NvBool      NV_API_CALL  os_is_vgx_hyper             (void);
 NV_STATUS   NV_API_CALL  os_inject_vgx_msi           (NvU16, NvU64, NvU32);
+NvBool      NV_API_CALL  os_is_grid_supported        (void);
 NV_STATUS   NV_API_CALL  os_get_screen_info          (NvU64 *, NvU64 *);
 void        NV_API_CALL  os_bug_check                (NvU32, const char *);
 NV_STATUS   NV_API_CALL  os_lock_user_pages          (void *, NvU64, void **);
@@ -226,5 +227,6 @@ void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
 #define OS_PAGE_SHIFT               (os_get_page_shift())
 
 #define IS_VGX_HYPER()              os_is_vgx_hyper()
+#define IS_GRID_SUPPORTED()         os_is_grid_supported()
 
 #endif /* _OS_INTERFACE_H_ */
